{ nixpkgs ? import <nixpkgs> {} }:

let

  config = {
    packageOverrides = pkgs: with pkgs.haskell.lib;  with pkgs.lib; {
      haskell = pkgs.haskell // {
        packages = pkgs.haskell.packages // {
          ghcjs84 = pkgs.haskell.packages.ghcjs84.override {
            overrides = self: super: {
              doctest = null;
              directory-tree = dontCheck (super.directory-tree);
              http-types = dontCheck (super.http-types);
              tasty-quickcheck = dontCheck (super.tasty-quickcheck);
              scientific = dontCheck (super.scientific);
              servant = dontCheck (super.servant);
              jsaddle-warp = super.callPackage ./jsaddle-warp-ghcjs.nix {};
              ghc = overrideDerivation (super.ghc.override {
                ghcjsSrc = pkgs.fetchgit {
                  url = "https://github.com/ghcjs/ghcjs.git";
                  rev = "dc190b1bb2453cfa484124e9f335ee3cad1492f7";
                  sha256 = "0dh52aj0f3700zfyrhisy44b6y9p1bsawwrmd5pllpdyw21zd9lw";
                  fetchSubmodules = true;
                };
              }) (drv: { patches = (drv.patches or []) ++ [ ./ghcjs.patch ]; });
            };
          };
        };
      };
    };
  };
  pinnedVersion = nixpkgs.lib.importJSON ./nixpkgs-version.json;
  pinnedPkgs = import (nixpkgs.fetchFromGitHub {
    owner = "NixOS";
    repo = "nixpkgs";
    inherit (pinnedVersion) rev sha256;
  }) { inherit config; };
  inherit (pinnedPkgs) pkgs;

  in

{
  ghc = import ./default.nix { nixpkgs = pinnedPkgs; haskellPackages = pinnedPkgs.haskell.packages.ghc843; };
  ghcjs = import ./default.nix { nixpkgs = pinnedPkgs; haskellPackages = pinnedPkgs.haskell.packages.ghcjs84; };
}
